import { defineNuxtModule, addVitePlugin, addWebpackPlugin } from '@nuxt/kit';
import vitePluginEslint from 'vite-plugin-eslint';
import EslintWebpackPlugin from 'eslint-webpack-plugin';

const name = "@nuxtjs/eslint-module";
const version = "4.0.0";

const module = defineNuxtModule({
  meta: {
    name,
    version,
    configKey: "eslint",
    compatibility: {
      bridge: true
    }
  },
  defaults: {
    cache: true,
    exclude: ["**/node_modules/**"],
    extensions: ["js", "jsx", "ts", "tsx", "vue"],
    eslintPath: "eslint",
    emitError: true,
    emitWarning: true,
    failOnError: false,
    failOnWarning: false,
    fix: false,
    formatter: "stylish",
    lintOnStart: true
  },
  setup(options, nuxt) {
    if (!nuxt.options.dev) {
      return;
    }
    nuxt.hooks.hookOnce("builder:watch", (_, path) => {
    });
    addVitePlugin(vitePluginEslint({
      ...options,
      include: options.extensions.map((ext) => `**/*.${ext}`)
    }), { server: false });
    addWebpackPlugin(new EslintWebpackPlugin({
      ...options,
      context: nuxt.options.srcDir,
      lintDirtyModulesOnly: !options.lintOnStart
    }), { server: false });
  }
});

export { module as default };
